==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Top/language/lang-turkish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_CATEGORY","Kategori");
define("_LVOTES","oy");
define("_HITS","Hit");
define("_TOPWELCOME","En yiler Sayfas:");
define("_READSTORIES","en ok okunan haber");
define("_COMMENTEDSTORIES","en ok yorumlanan haber");
define("_ACTIVECAT","en aktif kategori");
define("_READSECTION","en ok okunan makale");
define("_NEWSSUBMITTERS","en aktif haber ekleyici");
define("_NEWSSENT","haber");
define("_VOTEDPOLLS","en ok oylanan anket");
define("_MOSTACTIVEAUTHORS","en aktif editr");
define("_NEWSPUBLISHED","haber");
define("_READREVIEWS","en ok okunan izlenim");
define("_DOWNLOADEDFILES","en ok indirilen dosya");
define("_MOSTREADPAGES","en ok okunan sayfa");
define("_MOSTVOTEDSTORIES","most voted stories");
define("_POINTS","points");
define("_BESTRATEDSTORIES","best rated stories (based on 5 maximun points)");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Top/language/lang-turkish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_CATEGORY","Kategori");
define("_LVOTES","oy");
define("_HITS","Hit");
define("_TOPWELCOME","En yiler Sayfas:");
define("_READSTORIES","en ok okunan haber");
define("_COMMENTEDSTORIES","en ok yorumlanan haber");
define("_ACTIVECAT","en aktif kategori");
define("_READSECTION","en ok okunan makale");
define("_NEWSSUBMITTERS","en aktif haber ekleyici");
define("_NEWSSENT","haber");
define("_VOTEDPOLLS","en ok oylanan anket");
define("_MOSTACTIVEAUTHORS","en aktif editr");
define("_NEWSPUBLISHED","haber");
define("_READREVIEWS","en ok okunan izlenim");
define("_DOWNLOADEDFILES","en ok indirilen dosya");
define("_MOSTREADPAGES","en ok okunan sayfa");
define("_MOSTVOTEDSTORIES","most voted stories");
define("_POINTS","points");
define("_BESTRATEDSTORIES","best rated stories (based on 5 maximun points)");

?>
